@@ -94,4 +94,26 @@ board_test <- function(board, exclude = list(), destination = paste(board, "boar
     if (nrow(results) > 0)
       deps$fail(paste0("Pin '", paste(results$name, collapse = ","), "' still exists after removal."))
   })
+
+  deps$test_that(paste("can pin() medium files", destination), {
+    if ("remove" %in% exclude) deps$skip("This test is in the excluded list")
+
+    flights_file <- tempfile(fileext = ".csv")
+    on.exit(unlink(flights_file))
+
+    pin_get("nycflights13/flights") %>% utils::write.csv(flights_file)
+
+    flights_name <- paste0("flights", round(stats::runif(1, 1, 1000)))
+    result <- pin(flights_file, name = flights_name, board = board)
+    deps$expect_true(!is.null(result))
+
+    Sys.sleep(3)
+
+    result <- pin_remove(flights_name, board = board)
+    deps$expect_equal(result, NULL)
+
+    results <- pin_find(name = flights_name, board = board)
+    if (nrow(results) > 0)
+      deps$fail(paste0("Pin '", paste(results$name, collapse = ","), "' still exists after removal."))
+  })
 }
