@@ -14,7 +14,7 @@ test_that("can pin_find() packages with search term", {
 
 test_that("can pin_get() an specific resource", {
   expect_gt(
-    nrow(pin_get("hpiR/seattle_sales", board = "packages")),
+    nrow(pin_get("babynames/babynames", board = "packages")),
     10^4
   )
 })
